import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 * This application demonstrates highlight of data points.
 * Move mouse cursor on a series data point to highlight it.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements ItemListener,AdjustmentListener {

    Graph graph;
    BarSerie bs;

    JCheckBox is3D,isHorizontal;

    JScrollBar depth;

    public Main() {
	
	setTitle("The JetChart Library - Bar Series highlight demo");
	 
	// Values for the series
	double[] values={200,300,400,500,600,600,500,400,300,200};

	// Creates three bar series
	bs=new BarSerie(values,"Bar Series");
	bs.setColor(Color.blue);
	bs.setWidth(10);

	// Enables highlight
	bs.setHighlightEnabled(true);

	// Labels for chart
	String[] labels={"label1","label2","label3","label4","label5","label6",
			 "label7","label8","label9","label10"};

	// Creates graphic context, passing labels
	graph=new Graph(labels);

	graph.set3DSeriesInLineEnabled(false);
	graph.addSerie(bs);

	setChartProperties();

	// Adds the bar series to the graphic context
        Container ct=getContentPane();
	ct.add("Center",graph);
	graph.setBackground(Color.black);

	// Creates a top panel to lay out components
	createTopPanel();

	// Adds window adapter
	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		System.exit(0);
	    }
	});

	setSize(500,450);

	// Centers frame on the screen
	Dimension d=getToolkit().getScreenSize();
	setLocation((d.width-getSize().width)/2,(d.height-getSize().height)/2);

	setVisible(true);

    }

    // Event handler for 3D state and chart orientation
    public void itemStateChanged(ItemEvent evt) {
	if (evt.getSource()==is3D) {
	    graph.set3DEnabled(is3D.isSelected());
	    depth.setEnabled(is3D.isSelected());
	}
	else if (evt.getSource()==isHorizontal) {
	    boolean hor=isHorizontal.isSelected();
	    graph.setHorizontalGraphEnabled(hor);
	    if (!hor) {
		graph.getLeftTitle().setText("Values Title");
		graph.getBottomTitle().setText("Labels Title");
	    }
	    else {
		graph.getLeftTitle().setText("Labels Title");
		graph.getBottomTitle().setText("Values Title");
	    } 
	}
	graph.repaint();
    }

    // Event handler for chart depth adjustment
    public void adjustmentValueChanged(AdjustmentEvent evt) {
	if (evt.getSource()==depth) {
	    graph.setVDepth(depth.getValue());
	    graph.setHDepth(depth.getValue());
	    graph.repaint();
	}
    }
	    
	    
    // Creates top panel
    private void createTopPanel( ) {

	// Creates top panel with a border around
	JPanel topPanel=new JPanel();

	topPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
	
	//  Checkbox for 3D property.
	is3D=new JCheckBox("3D");
	is3D.setFont(new Font("Arial",Font.PLAIN,10));
        is3D.setSelected(true);
	is3D.addItemListener(this);

	// Checkbox for chart orientation property
	isHorizontal=new JCheckBox("Horizontal");
	isHorizontal.setFont(new Font("Arial",Font.PLAIN,10));
	isHorizontal.addItemListener(this);

	// Scrollbar for chart depth adjustment
	depth=new JScrollBar(JScrollBar.HORIZONTAL,5,1,0,30);
        depth.setPreferredSize(new Dimension(150,depth.getPreferredSize().height));
	
	depth.addAdjustmentListener(this);
	
	topPanel.add(is3D);
	topPanel.add(isHorizontal);
	topPanel.add(new Label("3D depth:"));
	topPanel.add(depth);
    
        Container ct=getContentPane();

	ct.add("North",topPanel);

    }

    private void setChartProperties() {

	// Sets chart title
	String[] title={"The JetChart Library","Highlight demo"};
	graph.setTitle(title);
	graph.setTitleForeground(Color.green);
	
	// Sets labels title
	graph.getBottomTitle().setText("Labels Title");

	// Sets values title
	graph.getLeftTitle().setText("Values Title");

	// Enables chart and legend dragging. A double-click over chart alternates
	// between moving chart and scale adjustment.
	graph.setDraggingEnabled(true);

	graph.set3DEnabled(true);

	// Enables grid and sets grid color. See the GraphSet class documentation for
	// further details.
	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.getGraphSet(0).getGrid().setColor(Color.yellow);

	// Sets the labels color to red.
	graph.getGraphSet(0).setLabelsColor(Color.red);
	
	// Disables labels marks.
	graph.getGraphSet(0).setLabelsMarksEnabled(false);

	// Disables scale marks.
	Scale scale=graph.getGraphSet(0).getScale();
	scale.setMarksEnabled(false);

	// Sets scale color.
	scale.setColor(Color.red);

	// Sets 2D axis colors.
	graph.getGraphSet(0).getXAxis().setColor(Color.green.darker());
	graph.getGraphSet(0).getYAxis().setColor(Color.green.darker());
	

    }

    public static void main(String[] args) {
	new Main();
    }
}
 
