import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;
import java.applet.*;

/**
 * This example demonstrates how to refresh the values of a series
 * and repaint chart after a certain period of time.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements Runnable  {

    Graph graph;
    CandleStickSerie ohlc;
    Thread myThread;

    double[][] values1={{70,30,40,60},{75,50,70,55},{68,43,45,65},
		    {65,38,40,60},{73,43,60,51},{50,20,30,45},
		    {48,30,47,33},{65,40,50,65},{80,50,50,73},
		    {85,55,70,60}};
    double[][] values2={{75,50,70,55},{68,43,45,65},{70,30,40,60},
		    {50,20,30,45},{73,43,60,51},{65,38,40,60},
		    {65,40,50,65},{80,50,50,73},{85,55,70,60},
		    {48,30,47,33}};
    double[][] values3={{85,55,70,60},{80,50,50,73},{65,40,50,65},
			{48,30,47,33},{50,20,30,45},{73,43,60,51},
			{65,38,40,60},{68,43,45,65},{75,50,70,55},
			{70,30,40,60}};
    
    public Main() {

	setTitle("The JetChart Library - A live chart demo");

        addWindowListener(new WindowAdapter() {
           public void windowClosing(WindowEvent evt) {
              System.exit(0);
           }
        });

	// Creates candlestick series.
	ohlc=new CandleStickSerie(values1);

	ohlc.setTitle("Stock price");
	
	ohlc.setWidth(5);
	
	// Sets color of bearish candlesticks. Default is black.
	ohlc.setBearishColor(Color.red);
	// Sets color of bullish candlesticks. Default is white.
	ohlc.setBullishColor(Color.green);
	
	graph=new Graph();
	
	graph.setTitle(new String[]{"The JetChart Library","Live chart demo"});

	// Enables the primary GraphSet grid and sets its color.
	// See documentation for further details about the GraphSet class.
	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.getGraphSet(0).getGrid().setColor(Color.lightGray);
	
	// Disables automatic scale. Sets max value of scale to 120 with increment of 10.
	Scale scale=graph.getGraphSet(0).getScale();
	scale.setAutoScaleEnabled(false);
	scale.setIncrement(10);
	scale.setMaxValue(120);
	
	graph.addSerie(ohlc);
	
	// Sets a start date. Labels are automatically calculated from this date.
	graph.setStartDate("09012000");
	
	// Sets the date increment to be a daily increment with a two weeks interval.
	graph.setDateIncrement(Graph.DAY_INCREMENT,14);
	
        Container ct=getContentPane();

	ct.add("Center",graph);

	setSize(500,300);
	setVisible(true);

	Thread thread=new Thread(this);
	thread.start();
    }
    

    public void run() {

    f:
	while (true) {

	    // The chart is refreshed after a one second interval.
	    try {
		Thread.sleep(1000);
	    }
	    catch (InterruptedException e) {
		e.printStackTrace();
	    }
	    
	    // Fetches the ohlc series values.
	    double[][] values=ohlc.getMultipleValues();
	    
	    // Alternates series values sequentially. At this point, values can be retrieved from a
	    // database, replacing the old values in the ohlc series array of double numbers.
	    if (values==values1)
		ohlc.setMultipleValues(values2);
	    else if (values==values2)
		ohlc.setMultipleValues(values3);
	    else if (values==values3)
		ohlc.setMultipleValues(values1);
	    
	    // Refreshes the chart, repainting it and displaying the new values.
	    graph.refresh();
	}
    }
    

    public static void main(String[] args) {

	// Creates the applet
	Main main=new Main();

    }

}
