import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;
import java.util.*;

import java.io.*;

/**
 * This demo displays two series, one showing a sequence of stock prices over
 * a period of 6 months and the other showing the sales volume.
 * 
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements ItemListener,ActionListener {

    Graph graph;

    GraphSet lowerGraphSet;
    
    JComboBox upperIndicator,lowerIndicator;

    OHLCSerie os;

    GraphSerie gs;
    LineSerie ls;
    JLabel openLabel,highLabel,lowLabel,closeLabel,volumeLabel;

    JCheckBox cbToolTip,cbTrendLine;
    JButton delTrendLines;

    public Main() {

        setTitle("The JetChart Library - OHLC chart demo");

        addWindowListener(new WindowAdapter() {
           public void windowClosing(WindowEvent evt) {
              System.exit(0);
           }
        });
	
	JPanel topPanel=new JPanel();
	topPanel.setLayout(new FlowLayout(FlowLayout.LEFT));

        String[] items={"OHLC bars","HLC bars","Line - OHLC Tooltips","Line - HLC Tooltips",
                        "Candlesticks"};
	upperIndicator=new JComboBox(items);
	upperIndicator.setFont(new Font("SansSerif",Font.PLAIN,10));
	upperIndicator.addItemListener(this);

        items=new String[]{"Bar chart","Area chart","Line chart"};
        lowerIndicator=new JComboBox(items);
	lowerIndicator.setFont(new Font("SansSerif",Font.PLAIN,10));
	lowerIndicator.addItemListener(this);

	cbToolTip=new JCheckBox("Show tooltips",false);
	cbToolTip.setFont(new Font("SansSerif",Font.PLAIN,10));

	cbToolTip.addItemListener(this);

	cbTrendLine=new JCheckBox("Draw trendlines");
	cbTrendLine.setFont(new Font("SansSerif",Font.PLAIN,10));
	cbTrendLine.addItemListener(this);

	delTrendLines=new JButton("Delete trendlines");
	delTrendLines.setFont(new Font("SansSerif",Font.PLAIN,10));
	delTrendLines.addActionListener(this);

	GridBagLayout gb=new GridBagLayout();
	GridBagConstraints gbc=new GridBagConstraints();
	gbc.gridwidth=GridBagConstraints.REMAINDER;
	gbc.anchor=GridBagConstraints.WEST;
	gbc.insets=new Insets(5,5,5,5);

	JPanel leftPanel=new JPanel(new GridBagLayout());
	leftPanel.setBorder(BorderFactory.createEtchedBorder());

	leftPanel.add(cbTrendLine,gbc);
	leftPanel.add(delTrendLines,gbc);

	JLabel upperIndicatorLabel=new JLabel("Upper Indicator");
	upperIndicatorLabel.setFont(new Font("SansSerif",Font.PLAIN,10));
	JLabel lowerIndicatorLabel=new JLabel("Lower Indicator");
	lowerIndicatorLabel.setFont(new Font("SansSerif",Font.PLAIN,10));

	upperIndicatorLabel.setBackground(Color.yellow);
	topPanel.add(upperIndicatorLabel);
	topPanel.add(upperIndicator);
	topPanel.add(lowerIndicatorLabel);
	topPanel.add(lowerIndicator);

	topPanel.add(cbToolTip);
	//topPanel.add(cbTrendLine);

        Container ct=getContentPane();

	ct.add("North",topPanel);

	ct.add("West",leftPanel);

	// Creates the chart context and sets several properties.
	createGraph();

	/**
	 * Creates a new  GraphSet  to  display   the  volume series values  within a 
	 * secondary scale. A GraphSet  consists  of  a  scale, a  grid, a horizontal
	 * axis,  two  vertical axis(left and right),  a scrolling bar, a series base,
	 * a chart wall and a group of series.
	 * An  unlimited  number   of   GraphSet   objects  can   be   added   to the
	 * chart context. GraphSet objects do not interact with each other, they  are  
	 * completely independent, giving great flexibility to JetChart.
	 */
	createGraphSet();

	/**
	 * Sets the properties  of  the primary GraphSet. JetChart  keeps  a primary
         * GraphSet object. At initialization time, all GraphSet objects are checked
	 * to  detect series  that were not added to them. The series detected   are
	 * added to the primary GraphSet.
	 */
	setPrimaryGraphSetProperties();
	
	/**
	 * Creates two series, an ohlc series with stock prices and a bar series with
	 * sales volume.
	 */
	createLowerSeries();
	createUpperSeries();

	ct.add(BorderLayout.CENTER,graph);

        // Creates a bottom panel to display OHLC values if tooltips display is disabled.
	JPanel bottomPanel=createBottomPanel();
	
	ct.add("South",bottomPanel);

        setSize(700,450);
        setVisible(true);

    }

    private JPanel createBottomPanel() {
	
	JPanel bottomPanel=new JPanel(new FlowLayout(FlowLayout.LEFT));

        // Creates  ohlc labels and sets their sizes, overriding the preferred size.
        openLabel=createLabel();
	highLabel=createLabel();
	lowLabel=createLabel();
	closeLabel=createLabel();
	volumeLabel=createLabel();

        // Adds the ohlc labels to the bottom panel.
	bottomPanel.add(new JLabel("High:",Label.RIGHT));
	bottomPanel.add(highLabel);
	bottomPanel.add(new JLabel("Low:",Label.RIGHT));
	bottomPanel.add(lowLabel);
	bottomPanel.add(new JLabel("Open:",Label.RIGHT));
	bottomPanel.add(openLabel);
	bottomPanel.add(new JLabel("Close:",Label.RIGHT));
	bottomPanel.add(closeLabel);
	bottomPanel.add(new JLabel("Volume:",Label.RIGHT));
	bottomPanel.add(volumeLabel);

	return bottomPanel;

    }

    private JLabel createLabel() {
	
	// Creates a Label and sets its width to 50 pixels.
       JLabel l=new JLabel();
       l.setPreferredSize(new Dimension(50,24));

       return l;
    }

    private void createGraph() {

	graph=new Graph();
	graph.setTitle(new String[]{"The JetChart Library - A financial chart"});

	// Sets Legend properties
	graph.getLegend().setOpacityEnabled(false);

	// Sets a start date. The dates and series values  usually come from a database.
	graph.setStartDate("01272001");

	// Enables month labels.
	graph.setMonthLabelsEnabled(true);
	
        // Creates a mouse listener adapter to handle mouse exit events and erase the text of
        // the ohlc labels.
	graph.addMouseListener(new MouseAdapter() {
   	        public void mouseExited(MouseEvent evt) {
		    
		    if (!graph.isDrawingTrendLine()) {
			openLabel.setText("");
			highLabel.setText("");
			lowLabel.setText("");
			closeLabel.setText(""); 
			volumeLabel.setText("");
		    }
		}

	    });


        /**
         * Creates  a  series listener adapter to  handle series  events  dispatched  if mouse is moved
         * over the chart area. If chart is 2D and tooltips  display  is  disabled, a SerieEvent object
         * is dispatched to series event listeners. If  the   method setMultipleSerieEventsEnabled   of
         * the Graph class is set to true and mouse cursor is positioned over a vertical  or horizontal
         * area delimited by a label coordinate, depending on chart orientation,  multiple   SerieEvent
         * objects are dispatched simultaneously, all of them referring to data points sharing the same 
         * label coordinate. By checking  the  data  point index of a series with the getElementIndex() 
         * method of the SerieEvent class, it is possible  to  get  the values  of  that data point and
         * display them.
         * The mouseMoved method is only called if tooltips display is disabled and chart is 2D.
         */
	graph.addSerieListener(new SerieAdapter() {

		public void mouseMoved(SerieEvent evt) {
		    AbstractSerie as=evt.getSerie();
		 
                    /**
                     * Checks if the series reference held by the SerieEvent object is the
                     * OHLC Series.
                     */
		    if (as==os) {

                        /**
                         * To get the values of an OHLC series, use the method getMultipleValues()
                         * of the AbstractSerie class.
                         */
			double values[][]=as.getMultipleValues();

                        /**
                         * An index different from -1 means that the mouse cursor is within a
                         * data point bounds.
                         */
			if (evt.getElementIndex()!=-1) {
			    highLabel.setText(Double.toString(values[evt.getElementIndex()][0]));
			    lowLabel.setText(Double.toString(values[evt.getElementIndex()][1]));
			    openLabel.setText(Double.toString(values[evt.getElementIndex()][2]));
			    closeLabel.setText(Double.toString(values[evt.getElementIndex()][3]));;
			} 
                        /**
                         * If the OHLC series element index is -1, mouse cursor is positioned outside
                         * data point bounds. Erases the text displayed in the ohlc labels.
                         */
			else {
			    openLabel.setText("");
			    highLabel.setText("");
			    lowLabel.setText("");
			    closeLabel.setText("");
			}
			
		    }

		    /**
                     * Checks if the series reference held by the SerieEvent object is any series other 
                     * than an OHLC series.
                     */
		    else if (as==gs) {

                        /**
                         * To get the value of any series other than OHLC series, use the method getValues()
                         * of the AbstractSerie class.
                         */
			double[] values=as.getValues();

			if (evt.getElementIndex()!=-1)
			    volumeLabel.setText(Double.toString(values[evt.getElementIndex()]));
			else
			    volumeLabel.setText("");
		    }

		}

	    });
	
	
	// Enables zoom. To select an area to be zoomed-in, click mouse button and drag. After finishing
	// selection, just release button. The selected area is zoomed-in. 
	// To return chart to its original state, click mouse right-button.
	// If chart dragging is enabled, this method has no effect.
	graph.setZoomEnabled(true);

	// Enables splitting of selected zoom area, which will only be painted within each GraphSet object
	// bounds.
	graph.setZoomAreaSplitEnabled(true);

	// Sets the color to paint zoom selected area. The color is painted in XOR mode. While in this
	// mode, the color informed is combined with the background color, resulting in a transparent
	// effect. Default color is blue.
	//graph.setZoomAreaColor(Color.lightGray);

        /**
         * Enables multiple dispatch of series events to registered SerieListener objects.
         * This  method   only   affects   dispatch   of   series   event  while   moving 
         * mouse cursor over the chart area. It is not related to series events dispatched
         * if a series data point is clicked, released or dragged.
         */ 
	graph.setMultipleSerieEventsEnabled(true);

	// Enables simultaneous highlight of data points.
	graph.setMultipleHighlightEnabled(true);

        // Sets tooltips properties.
        setToolTipProperties();
       
	/**
	 * An OHLC chart can display a scrolling   label.
	 * The scrolling label is only displayed if chart
	 * is 2D and orientation is vertical.
	 */
	graph.getScrollingLabel().setEnabled(true);

	// Sets scrolling label description.
	graph.getScrollingLabel().setDescription("Date:");

	// Sets scrolling label color.
	graph.getScrollingLabel().setColor(Color.red);

	// Sets chart background
	graph.setBackground(new Color(204,210,211));

	// Enables automatic positioning of scales along the vertical axis, so they don't overlap
	// each other.
	graph.setAutoScalePositioningEnabled(true);

        /**
         * The method below  controls  mouse  sensitivity,  which  is  related to multiple 
         * tooltips display,  dispatch  of  multiple series  events,   multiple highlight,
         * scrolling  label  and scrolling bar display. One of the following constants can 
         * be used to set mouse sensitivity:
         * Graph.LOW - Graph.MEDIUM - Graph.HIGH
         */
        //graph.setMouseSensitivity(Graph.LOW);
        
    }

    private void setToolTipProperties() {

       	// Enables simultaneous display of tooltips.
	graph.getToolTip().setMultipleEnabled(true);

        /**
	 * Sets the tooltip border color to be the same of its respective series.
	 * A series can be identified by checking its tooltip border color. 
         */
	graph.getToolTip().setMatchingBorderEnabled(true);

        /**
         * The tooltips matching borders are only displayed if the tooltip type
         * is set to NONE.
         */
        graph.getToolTip().setPointerType(ToolTip.NONE);

	// Sets tooltips background and font.
	graph.getToolTip().setBackground(Color.white);

    }

    private void setPrimaryGraphSetProperties() {
	
	/**
	 * Gets a reference to the primary GraphSet object. Each GraphSet object
	 * included in the chart   context  has  an  index. The primary GraphSet
	 * always has index 0.
	 */
	GraphSet upperGraphSet=graph.getGraphSet(0);
	
        // Sets the scale properties of the primary GraphSet.
	Scale scale=upperGraphSet.getScale();

	scale.setPosition(Scale.RIGHT);

	/**
	 * Disables automatic scale and set the maximum, minimum and increment
	 * values.
	 */
	scale.setAutoScaleEnabled(false);
	scale.setMaxValue(300);
	scale.setMinValue(30);
	scale.setIncrement(40);

        // Sets the scale value format.
	scale.setValueFormat("$ ###,###0.00");

	// Disables scale marks.
	scale.setMarksEnabled(false);

        // Enables the grid.
	upperGraphSet.getGrid().setEnabled(true);
	upperGraphSet.getGrid().setColor(Color.orange);

	// Sets trendlines color and thickness.
	upperGraphSet.setTrendLinesColor(Color.blue);
	upperGraphSet.setTrendLinesThickness(2);

	/**
	 * Enables the scrolling bar. A scrolling bar is displayed   across
	 * the chart area while moving mouse. It is only displayed if chart
	 * is 2D.
	 */
	ScrollingBar scrollingBar=upperGraphSet.getScrollingBar();
	scrollingBar.setEnabled(true);

	// Enables the grid crossed lines and sets its color to gray.
	GridCrossedLines gridCrossedLines=upperGraphSet.getGridCrossedLines();
	gridCrossedLines.setEnabled(true);
	gridCrossedLines.setColor(Color.lightGray);
	
	// Enables the chart wall and sets its color.
	Wall wall=upperGraphSet.getWall();
	wall.setEnabled(true);
	wall.setColor(new Color(255,255,214));

	// Enables wall shadow.
	wall.setShadowEnabled(true);

	// Disables labels marks.
	upperGraphSet.setLabelsMarksEnabled(false);

        // Disables the left and right vertical axis.
        upperGraphSet.getYAxis().setEnabled(false);
        upperGraphSet.getRYAxis().setEnabled(false);


    }

    private void createGraphSet() {

        // Creates the secondary GraphSet object.
	lowerGraphSet=new GraphSet();
	
        // Includes the GraphSet object in the chart context.
	graph.addGraphSet(lowerGraphSet);

        // Sets the scale properties of the secondary GraphSet object.
	Scale scale=lowerGraphSet.getScale();

	// Disables automatic scale and sets increment and maximum scale value.
	scale.setAutoScaleEnabled(false);
	scale.setIncrement(20);
	scale.setMaxValue(160);

        // Sets the scale to be displayed on the left and right vertical axis.
	scale.setPosition(Scale.LEFT_RIGHT);

        // Sets the scale value format.
	scale.setValueFormat("###,### M");

        // Sets the scale font and color.
	scale.setFont(new Font("Monospaced",Font.ITALIC,12));
	scale.setColor(Color.blue.darker());
	
	// Disables scale marks.
	lowerGraphSet.getScale().setMarksEnabled(false);

	// Enabled the grid of the secondary GraphSet.
	Grid grid=lowerGraphSet.getGrid();
	grid.setEnabled(true);

        // Activates grid colored bands.
	grid.setColoredBandsEnabled(true);

	// Enables chart wall and its shadow.
	Wall wall=lowerGraphSet.getWall();
	wall.setEnabled(true);
	wall.setShadowEnabled(true);

	// Disables labels marks.
	lowerGraphSet.setLabelsMarksEnabled(false);

	// Enables grid crossed lines and sets its color to red.
	GridCrossedLines gridCrossedLines=lowerGraphSet.getGridCrossedLines();
	gridCrossedLines.setEnabled(true);
	gridCrossedLines.setColor(Color.red);
	
	// Enables scrolling bar.
	ScrollingBar scrollingBar=lowerGraphSet.getScrollingBar();
	scrollingBar.setEnabled(true);

        // Disables the left and right vertical axis.
        lowerGraphSet.getYAxis().setEnabled(false);
        lowerGraphSet.getRYAxis().setEnabled(false);

	// Sets trendlines color and thickness.
	lowerGraphSet.setTrendLinesColor(Color.red);
	lowerGraphSet.setTrendLinesThickness(2);

    }

    public void actionPerformed(ActionEvent evt) {


	if (evt.getSource()==delTrendLines) {
	    graph.getGraphSet(0).removeAllTrendLines();
	    lowerGraphSet.removeAllTrendLines();
	    graph.repaint();
	}
    }

    public void itemStateChanged(ItemEvent evt) {

        /**
         * Toggles display of  tooltips. If  tooltips  are enabled, data  points  values
         * are not displayed in the bottom panel. Series events are not dispatched   to
	 * the method mouseMoved of SerieListener objects if tooltips are enabled.
         */
	if (evt.getSource()==cbToolTip)
	    graph.getToolTip().setEnabled(cbToolTip.isSelected());

	if (evt.getSource()==cbTrendLine) {
	    graph.setTrendLinesDrawingEnabled(cbTrendLine.isSelected());
	    if (cbTrendLine.isSelected())
		graph.setDefaultCursor(Cursor.getPredefinedCursor(Cursor.CROSSHAIR_CURSOR));
	    else
		graph.setDefaultCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
	}

        /**
         * Removes the upper series and creates a new one, according to the index of the
         * upperIndicator component.
         */
	if (evt.getSource()==upperIndicator) {
	    graph.removeSerie(os);
	    createUpperSeries();
	}
        /**
         * Removes the lower series and creates a new one, according to the index of the
         * lowerIndicator component.
         */
	else if (evt.getSource()==lowerIndicator) {

	    graph.removeSerie(gs);

            /**
             * Removes the secondary  GraphSet series. If it is  not 
             * removed, JetChart  raises an   exception, because the 
             * GraphSet will be keeping a reference to a series that
             * was removed from the chart context.
             */
	    lowerGraphSet.removeSerie(gs);

	    createLowerSeries();
	}
	graph.refresh();

    }
	
    private void createLowerSeries() {
	double[] lowerSeriesValues=getLowerSeriesValues();
	
	int index=lowerIndicator.getSelectedIndex();
	switch (index) {
	case 0: {
	    gs=new BarSerie(lowerSeriesValues,"Sales Volume");
	    BarSerie bs=(BarSerie)gs;
	    bs.setBorderEnabled(false);
	    bs.setColor(Color.blue);
	    bs.setWidth(2);
	    break;
	}
	case 1: {
	    gs=new AreaSerie(lowerSeriesValues,"Sales Volume");
	    AreaSerie as=(AreaSerie)gs;
	    as.setAreaLinesEnabled(false);
	    as.setColor(Color.blue);
	    as.setHighlightEnabled(true);
	    break;
	}
	case 2: {
	    gs=new LineSerie(lowerSeriesValues,"Sales Volume");
	    LineSerie ls=(LineSerie)gs;
	    ls.setMarksEnabled(false);
	    ls.setColor(Color.blue);
	    ls.setHighlightEnabled(true);
	}
	}
	graph.addSerie(gs);

	// Sets the series title to be displayed beside the top of the y axis.
	gs.setTitlePosition(GraphSerie.BESIDE_TOP_YAXIS);

	// Sets the series title font. 
	gs.setTitleFont(new Font("SansSerif",Font.PLAIN,12));

	// Adds the sales volume series to the secondary graph set.
	lowerGraphSet.addSerie(gs);
    }

    private void createUpperSeries() {

	double[][] upperSeriesValues=getUpperSeriesValues();
	
  	 // Creates OHLC series.
	int index=upperIndicator.getSelectedIndex();
	switch (index) {
	case 0: {
	    os=new OHLCBarSerie(upperSeriesValues);
	    os.setType(OHLCBarSerie.BAR_OHLC);
	    ((OHLCBarSerie)os).setWidth(1);

            // Sets the bullish and bearish colors of the OHLC bar series.
	    ((OHLCBarSerie)os).setBullishColor(Color.green.darker());
	    ((OHLCBarSerie)os).setBearishColor(Color.red);

	    ((OHLCBarSerie)os).setDashSize(1);

	    break;
	}
	case 1: {
	    os=new OHLCBarSerie(upperSeriesValues);
	    os.setType(OHLCBarSerie.BAR_HLC);
	    ((OHLCBarSerie)os).setWidth(1);
	    ((OHLCBarSerie)os).setBullishColor(Color.green.darker());
	    ((OHLCBarSerie)os).setBearishColor(Color.red);
	    ((OHLCBarSerie)os).setDashSize(1);

	    break;
	}
	case 2: {
	    os=new OHLCLineSerie(upperSeriesValues);
	    os.setType(OHLCLineSerie.LINE_OHLC);
	    ((OHLCLineSerie)os).setThickness(2);
	    ((OHLCLineSerie)os).setMarksEnabled(false);
	    ((OHLCLineSerie)os).setHighlightEnabled(true);

	    break;
	}
	case 3: {
	    os=new OHLCLineSerie(upperSeriesValues);
	    os.setType(OHLCLineSerie.LINE_HLC);
	    ((OHLCLineSerie)os).setThickness(2);
 	    ((OHLCLineSerie)os).setMarksEnabled(false);
	    ((OHLCLineSerie)os).setHighlightEnabled(true);
	    break;
	}
	case 4: {
	    os=new CandleStickSerie(upperSeriesValues);
	    ((CandleStickSerie)os).setWidth(5);
	    ((CandleStickSerie)os).setBullishColor(Color.green.darker());
	    ((CandleStickSerie)os).setBearishColor(Color.red);
	    ((CandleStickSerie)os).setLegendEnabled(true);

	}
	}
	
	os.setTitle("Stock prices");

	// Sets the series title to be displayed beside the top of the y axis.
	os.setTitlePosition(GraphSerie.BESIDE_TOP_YAXIS);
	
	// Sets the series title font. 
	os.setTitleFont(new Font("SansSerif",Font.PLAIN,12));

	
	os.setType(index);
	os.setColor(Color.green.darker());

        /**
	 * Adds  the  stock prices series to the chart context. This  series  is  automatically
	 * added to the primary GraphSet object, since it wasn't added to a secondary graph set.
         */
	graph.addSerie(os);

    }
    
     private double[][] getUpperSeriesValues() {
	    
	double[][] values={{185.00,178.00,179.00,182.50},{196.00,183.50,183.95,192.90},
			   {196.95,189.20,194.00,190.00},{195.50,186.55,191.00,187.25},
			   {195.60,190.00,192.00,192.00},{207.35,190.10,191.10,207.35},
			   {214.00,193.10,211.25,196.15},{202.80,189.50,196.00,196.45},
			   {206.35,194.30,197.00,199.00},{208.00,197.00,204.00,198.10},
			   {205.00,182.30,199.00,182.95},{189.70,182.80,184.00,184.50},
			   {188.00,180.00,185.00,182.60},{184.45,173.15,184.00,174.10},
			   {180.00,173.00,178.00,174.25},{178.00,167.05,175.00,169.00},
			   {173.80,159.10,170.00,160.90},{165.50,160.00,163.00,163.75},
			   {173.00,161.10,163.00,163.20},{174.50,167.00,168.00,174.10},
			   {179.50,160.20,174.60,160.20},{163.90,154.00,160.10,161.30},
			   {163.20,148.40,161.95,148.40},{146.50,136.55,144.60,136.55},
			   {147.45,146.10,147.45,147.45},{159.20,141.50,155.10,154.00},
			   {153.00,142.10,153.00,143.10},{146.00,136.00,146.00,138.50},
			   {139.10,130.00,139.00,131.35},{137.70,125.75,134.00,128.45},
			   {138.25,127.00,128.50,134.90},{144.20,134.00,134.00,135.70},
			   {136.30,128.00,134.50,128.00},{132.50,126.30,132.00,128.85},
			   {139.10,129.40,129.40,139.10},{143.00,135.00,141.90,135.00},
			   {137.00,132.10,136.75,133.70},{139.90,130.25,137.00,131.85},
			   {137.50,127.00,130.95,137.40},{138.40,129.05,137.80,130.45},
			   {132.85,127.00,130.00,131.50},{142.00,128.00,129.15,140.40},
			   {151.60,140.00,141.00,151.60},{159.85,139.50,155.00,143.95},
			   {155.45,140.00,145.80,155.45},{163.90,150.00,161.40,154.75},
			   {167.10,155.90,156.50,167.10},{175.00,164.00,169.80,166.00},
			   {165.00,157.05,165.00,160.00},{162.00,154.20,159.00,154.80},
			   {154.00,143.75,154.00,145.25},{156.85,134.10,135.10,155.00},
			   {160.00,149.00,155.25,152.00},{156.00,144.65,153.50,148.50},
			   {148.00,139.00,148.00,143.85},{152.85,143.50,149.90,144.95},
			   {144.20,135.00,144.20,139.90},{150.75,139.90,142.00,149.00},
			   {149.00,140.55,149.00,142.70},{143.50,138.60,143.45,139.00},
			   {144.80,128.00,142.15,128.70},{131.45,124.50,128.00,129.70},
			   {130.25,122.60,129.00,125.85},{128.40,120.00,126.50,124.10},
			   {127.30,122.65,125.00,123.00},{128.95,115.50,123.00,126.95},
			   {128.85,120.10,127.00,120.65},{122.85,116.00,120.00,120.20},
			   {122.00,111.75,120.50,112.60},{118.35,108.50,118.35,111.50},
			   {114.40,110.25,112.00,110.50},{113.90,109.10,112.00,110.80},
			   {112.50,107.20,111.00,108.60},{108.50,105.75,107.35,106.20},
			   {107.35,95.50,105.00,96.80},{102.50,96.00,97.50,99.50},
			   {108.00,97.00,99.00,106.45},{115.50,106.75,106.90,114.40},
			   {126.00,113.00,114.00,125.50},{130.00,123.00,128.40,124.00},
			   {125.00,118.50,125.00,120.90},{123.85,112.20,122.00,113.50},
			   {113.20,103.00,112.25,109.20},{112.00,107.00,107.00,110.70},
			   {117.95,112.60,113.00,113.05},{114.35,110.00,114.00,112.00},
			   {114.45,111.20,111.70,112.30},{118.00,112.20,113.00,117.15},
			   {122.20,116.50,118.00,117.65},{123.40,118.55,120.00,119.65},
			   {122.00,118.30,119.00,120.30},{126.80,120.50,120.50,123.10},
			   {124.80,121.15,123.30,121.60},{123.00,119.10,121.50,122.70},
			   {126.70,121.50,124.95,122.50},{125.00,118.00,123.90,119.55},
			   {120.80,115.50,119.90,115.90},{117.30,114.00,116.40,116.80},
			   {119.50,115.10,116.00,116.00},{117.75,114.00,114.60,116.20},
			   {121.00,116.00,116.60,118.15},{120.00,117.30,118.85,117.95},
			   {123.50,118.20,118.75,122.00},{122.80,117.50,122.10,117.95},
			   {125.00,118.60,120.00,120.70},{128.00,120.75,121.10,127.00},
			   {133.25,127.00,127.75,127.30},{128.70,124.80,126.15,125.20},
			   {131.25,125.00,125.90,129.45},{134.40,128.70,131.80,129.85},
			   {132.15,128.00,130.40,130.35},{136.80,130.05,130.90,136.15},
			   {138.40,132.00,136.90,132.25},{135.85,130.60,133.00,134.00},
			   {139.90,134.50,136.00,139.30},{140.90,136.40,139.00,137.55},
			   {137.50,129.55,136.50,132.10},{133.60,123.05,132.30,126.10},
			   {128.50,120.60,127.20,121.35},{120.00,107.00,117.00,110.10},
			   {117.40,106.10,109.00,114.85},{119.00,106.25,116.00,107.45},
			   {109.80,103.00,106.20,107.85},{109.50,104.35,107.50,106.50},
			   {110.05,105.10,105.10,108.00},{115.40,104.00,107.35,113.05},
			   {118.85,110.10,112.50,116.70},{119.40,112.25,117.50,112.80},
			   {116.00,111.55,113.70,114.65},{115.75,107.50,114.40,109.05},
			   {115.90,106.15,109.70,115.20},{119.50,115.50,115.90,117.40},
			   {117.90,114.00,117.00,115.95},{121.00,113.25,115.00,120.65},
			   {126.00,119.75,121.25,125.00},{126.90,120.10,126.00,121.45},
			   {121.30,112.20,121.00,113.15},{115.25,113.05,113.90,113.95},
			   {117.00,114.10,115.50,115.70},{117.80,115.20,115.95,116.40},
			   {119.80,116.00,116.25,116.65},{117.70,113.00,117.40,116.10},
			   {124.80,115.00,116.50,121.80},{128.10,122.10,123.25,124.70},
			   {126.50,122.70,124.10,124.20},{125.45,121.60,125.00,123.30},
			   {126.75,122.50,123.80,124.50},{127.50,122.10,126.00,123.55},
			   {125.50,121.35,122.30,121.55},{121.20,117.55,121.20,118.40}};

	return values;

    }
 
    private double[] getLowerSeriesValues() {
	
	double[] values={131.90,132.80,130.50,131.00,136.75,135.00,131.50,130.50,
			 132.40,133.30,130.90,123.40,122.25,118.00,120.00,116.10,
			 115.00,103.45,107.50,103.80,99.00,96.75,94.00,95.90,97.50,
			 98.40,100.20,102.00,110.40,104.50,108.70,107.75,107.45,
			 103.00,100.90,99.25,93.80,99.25,103.00,100.25,102.70,
			 107.15,106.00,107.15,109.00,104.00,96.50,97.95,99.70,
			 97.70,91.00,87.45,86.80,88.60,85.40,85.90,84.85,
			 76.55, 68.00,67.45,61.90,60.90,60.75,53.60,58.50,
			 57.20,51.25,48.50,45.75,46.90,52.55,51.40,54.00,
			 51.70,41.20,38.75,34.00,33.50,33.25,34.25,33.90,
			 30.00,33.50,34.95,31.45,26.95,28.40,30.90,28.90,
			 29.90,29.80,33.25,34.50,34.00,36.90,37.00,36.40,
			 34.70,37.50,38.30,39.40,43.50,45.80,48.70,46.45,
			 47.85,49.40,54.90,55.50,56.95,58.75,61.80,58.50,
			 59.90,61.20,65.50,67.50,66.75,65.45,66.50,68.10,
			 64.80,57.70,59.80,57.80,57.00,55.25,61.30,66.90,
			 66.00,61.00,57.90,59.50,55.90,55.75,56.00,59.40,
			 58.85,55.40,50.05,49.50,49.80,59.00,57.40,60.00,
			 68.50,73.60,77.50,80.90,79.90};
	
	return values;

    }

    public static void main(String[] args) {
	Main m=new Main();
    }

}

