import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;
import java.util.*;

/**
 * This demo displays three series, each one  representing  stock prices  of different
 * companies.
 *
 * author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame  implements ItemListener,ActionListener {

    Graph graph;

    Hashtable series,colors;

    double[][] values;
    String[] labels;
    
    JComboBox chartType;
    JComboBox symbol;
    JComboBox labelPosition;
    JButton addButton,removeButton;

    public Main() {

        setTitle("The JetChart Library - OHLC chart demo");

        addWindowListener(new WindowAdapter() {
           public void windowClosing(WindowEvent evt) {
              System.exit(0);
           }
        });
	
	series=new Hashtable();
	colors=new Hashtable();
	colors.put("MCCO",Color.black);
	colors.put("LMNB",Color.red);
	colors.put("EMBR",Color.blue);
	
	JPanel controlPanel=new JPanel();
	controlPanel.setLayout(new FlowLayout(FlowLayout.LEFT));

        String[] items={"OHLC bars","HLC bars","Line - OHLC Tooltips","Line - HLC Tooltips",
                        "Candlesticks"};

        chartType=new JComboBox(items);
	chartType.addItemListener(this);

        items=new String[]{"MCCO","LMNB","EMBR"};
        symbol=new JComboBox(items);
	
        items=new String[]{"Chart top","Above x axis"};
        labelPosition=new JComboBox(items);
	labelPosition.addItemListener(this);
	
	addButton=new JButton("Add");
	addButton.addActionListener(this);
	removeButton=new JButton("Remove");
	removeButton.addActionListener(this);
	
	controlPanel.add(chartType);
	controlPanel.add(new JLabel("Symbol:"));
	controlPanel.add(symbol);
	controlPanel.add(addButton);
	controlPanel.add(removeButton);
	controlPanel.add(new JLabel("Scrolling Label pos.:"));
	controlPanel.add(labelPosition);

        Container ct=getContentPane();
	ct.add("North",controlPanel);


	// Creates the chart context and sets several properties.
	createGraph();

        graph.setAutoScalePositioningEnabled(true);
        graph.setScalesGap(.3F);

        setPrimaryGraphSetProperties();

	ct.add(BorderLayout.CENTER,graph);

        setSize(600,350);
        setVisible(true);

    }

    private void createGraph() {
	graph=new Graph();
	
	graph.setTitle(new String[]{"Financial chart"});

	// Sets a background image.
	graph.setBackgroundImage(getToolkit().getImage("rain.jpg"),Graph.TILE);

	// Sets Legend properties
	graph.getLegend().setOpacityEnabled(false);
	graph.getLegend().setPosition(Legend.RIGHT);
	graph.setSerieDraggingEnabled(true);

	// Sets a start date. The dates  and series values are usually retrieved from a database.
	graph.setStartDate("01272001");
	graph.setMonthLabelsEnabled(true);

	// Disables decimals of values displayed in tooltips.
	graph.setValueFormat("###");

	// Enables tooltip.
	graph.getToolTip().setEnabled(true);
	
	// Disables tooltip timer.
	graph.getToolTip().setTimerEnabled(true);

	// Enables multiple tooltips.
	graph.getToolTip().setMultipleEnabled(true);

	// Sets the tooltip border color to be the same of its respective series.
	// The series can be identified by checking its tooltip border color. 
	// This property only has effect if the tooltip pointer type is set to NONE.
	graph.getToolTip().setMatchingBorderEnabled(true);

	// Sets tooltip pointer type to NONE. 
	graph.getToolTip().setPointerType(ToolTip.NONE);

	// Sets tooltips background and font.
	graph.getToolTip().setBackground(Color.white);

	// Enables the scrolling label.
	graph.getScrollingLabel().setEnabled(true);

	// Sets scrolling label color.
	graph.getScrollingLabel().setColor(Color.blue.darker());
	
	graph.setBackground(Color.decode("#649a9c"));


    }


    // Sets the properties of the primary GraphSet object. See JetChart documentation
    // abouth the GraphSet class for further details.
    private void setPrimaryGraphSetProperties() {

       GraphSet graphSet=graph.getGraphSet(0);

       Scale scale=graphSet.getScale();

       scale.setPosition(Scale.LEFT_RIGHT);
       scale.setValueFormat("$ ###.###");
       
       // Enables the scrolling bar. 
       ScrollingBar sb=graph.getGraphSet(0).getScrollingBar();
       sb.setEnabled(true);
	
	// Sets scrolling label description.
	graph.getScrollingLabel().setDescription("Date:");
	graph.getScrollingLabel().setFont(new Font("SansSerif",Font.BOLD,14));

       Grid grid=graphSet.getGrid();
       grid.setEnabled(true);

  
    }

    public void actionPerformed(ActionEvent evt) {

	// If the 'Add' button was clicked, and the series that corresponds to the
	// selected symbol was not created yet, creates it and saves a reference
	// in the Hashtable 'series'.
	String sym=(String)symbol.getSelectedItem();
	if (evt.getActionCommand().equals("Add")) {
	    if (!series.containsKey(sym)) {
		Color color=(Color)colors.get(sym);
		OHLCSerie ohlc=createSerie(sym,color);
		series.put(sym,ohlc);
		graph.addSerie(ohlc);

		graph.repaint();
		    
	    }
	}
	// If the 'Remove' button was clicked and the series that corresponds to 
	// the selected symbol was found in the 'series' Hashtable, removes it.
	else if (evt.getActionCommand().equals("Remove")) {
	    if (series.containsKey(sym)) {
		OHLCSerie ohlc=(OHLCSerie)series.get(sym);
		series.remove(sym);
		graph.removeSerie(ohlc);
		graph.repaint();
	    }
	}
	    
	    
    }

    public void itemStateChanged(ItemEvent evt) {

	// Changes the series type of all series added to the chart context.
	if (evt.getSource()==chartType) {
	    int index=chartType.getSelectedIndex();
	    Enumeration e=series.keys();
	    
	    Hashtable newSeries=new Hashtable();
	    
	    graph.removeAllSeries();

	    while (e.hasMoreElements()) {

		Object symbol=e.nextElement();
		Object color=colors.get(symbol);

		OHLCSerie os=(OHLCSerie)series.get(symbol);

		boolean createNewSerie=false;

		switch (index) {
		case 0: {
		    if (os instanceof OHLCBarSerie) {
			((OHLCBarSerie)os).setType(OHLCBarSerie.BAR_OHLC);
		    }
		    else
			createNewSerie=true;
		    break;
		}
		case 1: {
		    if (os instanceof OHLCBarSerie)
			((OHLCBarSerie)os).setType(OHLCBarSerie.BAR_HLC);
		    else
			createNewSerie=true;
		    break;
		}
		case 2: {
		    if (os instanceof OHLCLineSerie)
			((OHLCLineSerie)os).setType(OHLCLineSerie.LINE_OHLC);
		    else
			createNewSerie=true;
		    break;
		}
		case 3: {
		    if (os instanceof OHLCLineSerie) {
			((OHLCLineSerie)os).setType(OHLCLineSerie.LINE_HLC);
		    }
		    else
			createNewSerie=true;
		    break;
		}
		case 4: {
		    createNewSerie=!(os instanceof CandleStickSerie);
		    break;
		}
		}
		    
		if (createNewSerie) 
		    os=createSerie((String)symbol,(Color)color);

		newSeries.put(symbol,os);
		graph.addSerie(os);
		
	    }

	    series=newSeries;

	}
	else if (evt.getSource()==labelPosition) {
	    int index=labelPosition.getSelectedIndex();
	    graph.getScrollingLabel().setPosition(index);
	}
	graph.repaint();

    }
	
    private OHLCSerie createSerie(String symbol,Color color) {

	// Creates an OHLC series. Three symbols are listed here as examples. 

	double[][] values=null;

	// Gets the values of the selected symbol.
	if (symbol.equals("MCCO"))
	    values=getMCCOValues();
	else if (symbol.equals("LMNB"))
	    values=getLMNBValues();
	else if (symbol.equals("EMBR"))
	    values=getEMBRValues();

	// Creates the series, setting several properties.
	OHLCSerie os=null;
	int index=chartType.getSelectedIndex();
	switch (index) {
	case 0: {
	    os=new OHLCBarSerie(values);
	    os.setType(OHLCBarSerie.BAR_OHLC);
	    ((OHLCBarSerie)os).setWidth(1);
	    ((OHLCBarSerie)os).setDashSize(1);
	    break;
	}
	case 1: {
	    os=new OHLCBarSerie(values);
	    os.setType(OHLCBarSerie.BAR_HLC);
	    ((OHLCBarSerie)os).setWidth(1);
	    ((OHLCBarSerie)os).setDashSize(1);
	    break;
	}
	case 2: {
	    os=new OHLCLineSerie(values);
	    os.setType(OHLCLineSerie.LINE_OHLC);
	    //((OHLCLineSerie)os).setThickness(2);
	    ((OHLCLineSerie)os).setMarksEnabled(false);
	    break;
	}
	case 3: {
	    os=new OHLCLineSerie(values);
	    os.setType(OHLCLineSerie.LINE_HLC);
	    //((OHLCLineSerie)os).setThickness(2);
	    ((OHLCLineSerie)os).setMarksEnabled(false);
	    break;
	}
	case 4: {
	    os=new CandleStickSerie(values);
	    ((CandleStickSerie)os).setWidth(2);
	    ((CandleStickSerie)os).setBullishColor(Color.green);
	    ((CandleStickSerie)os).setBearishColor(Color.red);
	    ((CandleStickSerie)os).setLegendEnabled(true);
	}
	}
	
	os.setTitle(symbol);
	os.setType(index);
	os.setColor(color);
	os.setToolTipText(new String[]{"H:","L:","O:","C:"});

	return os;
    }
    
    // Values to the MCCO symbol.
    private double[][] getMCCOValues() {
	    
	double[][] values={{185.00,178.00,179.00,182.50},
			   {196.00,183.50,183.95,192.90},
			   {196.95,189.20,194.00,190.00},
			   {195.50,186.55,191.00,187.25},
			   {195.60,190.00,192.00,192.00},
			   {207.35,190.10,191.10,207.35},
			   {214.00,193.10,211.25,196.15},
			   {202.80,189.50,196.00,196.45},
			   {206.35,194.30,197.00,199.00},
			   {208.00,197.00,204.00,198.10},
			   {205.00,182.30,199.00,182.95},
			   {189.70,182.80,184.00,184.50},
			   {188.00,180.00,185.00,182.60},
			   {184.45,173.15,184.00,174.10},
			   {180.00,173.00,178.00,174.25},
			   {178.00,167.05,175.00,169.00},
			   {173.80,159.10,170.00,160.90},
			   {165.50,160.00,163.00,163.75},
			   {173.00,161.10,163.00,163.20},
			   {174.50,167.00,168.00,174.10},
			   {179.50,160.20,174.60,160.20},
			   {163.90,154.00,160.10,161.30},
			   {163.20,148.40,161.95,148.40},
			   {146.50,136.55,144.60,136.55},
			   {147.45,146.10,147.45,147.45},
			   {159.20,141.50,155.10,154.00},
			   {153.00,142.10,153.00,143.10},
			   {146.00,136.00,146.00,138.50},
			   {139.10,130.00,139.00,131.35},
			   {137.70,125.75,134.00,128.45},
			   {138.25,127.00,128.50,134.90},
			   {144.20,134.00,134.00,135.70},
			   {136.30,128.00,134.50,128.00},
			   {132.50,126.30,132.00,128.85},
			   {139.10,129.40,129.40,139.10},
			   {143.00,135.00,141.90,135.00},
			   {137.00,132.10,136.75,133.70},
			   {139.90,130.25,137.00,131.85},
			   {137.50,127.00,130.95,137.40},
			   {138.40,129.05,137.80,130.45},
			   {132.85,127.00,130.00,131.50},
			   {142.00,128.00,129.15,140.40},
			   {151.60,140.00,141.00,151.60},
			   {159.85,139.50,155.00,143.95},
			   {155.45,140.00,145.80,155.45},
			   {163.90,150.00,161.40,154.75},
			   {167.10,155.90,156.50,167.10},
			   {175.00,164.00,169.80,166.00},
			   {165.00,157.05,165.00,160.00},
			   {162.00,154.20,159.00,154.80},
			   {154.00,143.75,154.00,145.25},
			   {156.85,134.10,135.10,155.00},
			   {160.00,149.00,155.25,152.00},
			   {156.00,144.65,153.50,148.50},
			   {148.00,139.00,148.00,143.85},
			   {152.85,143.50,149.90,144.95},
			   {144.20,135.00,144.20,139.90},
			   {150.75,139.90,142.00,149.00},
			   {149.00,140.55,149.00,142.70},
			   {143.50,138.60,143.45,139.00},
			   {144.80,128.00,142.15,128.70},
			   {131.45,124.50,128.00,129.70},
			   {130.25,122.60,129.00,125.85},
			   {128.40,120.00,126.50,124.10},
			   {127.30,122.65,125.00,123.00},
			   {128.95,115.50,123.00,126.95},
			   {128.85,120.10,127.00,120.65},
			   {122.85,116.00,120.00,120.20},
			   {122.00,111.75,120.50,112.60},
			   {118.35,108.50,118.35,111.50},
			   {114.40,110.25,112.00,110.50},
			   {113.90,109.10,112.00,110.80},
			   {112.50,107.20,111.00,108.60},
			   {108.50,105.75,107.35,106.20},
			   {107.35,95.50,105.00,96.80},
			   {102.50,96.00,97.50,99.50},
			   {108.00,97.00,99.00,106.45},
			   {115.50,106.75,106.90,114.40},
			   {126.00,113.00,114.00,125.50},
			   {130.00,123.00,128.40,124.00},
			   {125.00,118.50,125.00,120.90},
			   {123.85,112.20,122.00,113.50},
			   {113.20,103.00,112.25,109.20},
			   {112.00,107.00,107.00,110.70},
			   {117.95,112.60,113.00,113.05},
			   {114.35,110.00,114.00,112.00},
			   {114.45,111.20,111.70,112.30},
			   {118.00,112.20,113.00,117.15},
			   {122.20,116.50,118.00,117.65},
			   {123.40,118.55,120.00,119.65},
			   {122.00,118.30,119.00,120.30},
			   {126.80,120.50,120.50,123.10},
			   {124.80,121.15,123.30,121.60},
			   {123.00,119.10,121.50,122.70},
			   {126.70,121.50,124.95,122.50},
			   {125.00,118.00,123.90,119.55},
			   {120.80,115.50,119.90,115.90},
			   {117.30,114.00,116.40,116.80},
			   {119.50,115.10,116.00,116.00},
			   {117.75,114.00,114.60,116.20},
			   {121.00,116.00,116.60,118.15},
			   {120.00,117.30,118.85,117.95},
			   {123.50,118.20,118.75,122.00},
			   {122.80,117.50,122.10,117.95},
			   {125.00,118.60,120.00,120.70},
			   {128.00,120.75,121.10,127.00},
			   {133.25,127.00,127.75,127.30},
			   {128.70,124.80,126.15,125.20},
			   {131.25,125.00,125.90,129.45},
			   {134.40,128.70,131.80,129.85},
			   {132.15,128.00,130.40,130.35},
			   {136.80,130.05,130.90,136.15},
			   {138.40,132.00,136.90,132.25},
			   {135.85,130.60,133.00,134.00},
			   {139.90,134.50,136.00,139.30},
			   {140.90,136.40,139.00,137.55},
			   {137.50,129.55,136.50,132.10},
			   {133.60,123.05,132.30,126.10},
			   {128.50,120.60,127.20,121.35},
			   {120.00,107.00,117.00,110.10},
			   {117.40,106.10,109.00,114.85},
			   {119.00,106.25,116.00,107.45},
			   {109.80,103.00,106.20,107.85},
			   {109.50,104.35,107.50,106.50},
			   {110.05,105.10,105.10,108.00},
			   {115.40,104.00,107.35,113.05},
			   {118.85,110.10,112.50,116.70},
			   {119.40,112.25,117.50,112.80},
			   {116.00,111.55,113.70,114.65},
			   {115.75,107.50,114.40,109.05},
			   {115.90,106.15,109.70,115.20},
			   {119.50,115.50,115.90,117.40},
			   {117.90,114.00,117.00,115.95},
			   {121.00,113.25,115.00,120.65},
			   {126.00,119.75,121.25,125.00},
			   {126.90,120.10,126.00,121.45},
			   {121.30,112.20,121.00,113.15},
			   {115.25,113.05,113.90,113.95},
			   {117.00,114.10,115.50,115.70},
			   {117.80,115.20,115.95,116.40},
			   {119.80,116.00,116.25,116.65},
			   {117.70,113.00,117.40,116.10},
			   {124.80,115.00,116.50,121.80},
			   {128.10,122.10,123.25,124.70},
			   {126.50,122.70,124.10,124.20},
			   {125.45,121.60,125.00,123.30},
			   {126.75,122.50,123.80,124.50},
			   {127.50,122.10,126.00,123.55},
			   {125.50,121.35,122.30,121.55},
			   {121.20,117.55,121.20,118.40},
			   {119.90,117.00,118.35,118.20},
			   {118.50,115.00,117.50,115.30},
			   {121.80,115.95,117.00,118.50},
			   {118.75,116.40,118.00,116.80},
			   {116.95,114.50,116.45,115.25},
			   {115.50,113.20,115.40,113.90},
			   {114.90,108.50,114.00,108.95},
			   {109.40,105.00,108.00,106.35},
			   {107.85,103.10,105.40,104.45},
			   {106.45,104.00,105.80,105.90},
			   {108.70,105.05,106.00,106.20},
			   {105.80,97.65,105.80,98.10},
			   {103.50,96.00,100.15,97.75},
			   {99.40,96.15,97.50,97.10},
			   {98.30,95.50,96.45,97.30},
			   {97.50,91.10,97.00,91.65},
			   {94.70,91.50,92.10,92.25},
			   {96.40,91.10,93.00,94.70},
			   {97.00,94.25,95.00,95.90},
			   {96.90,92.90,96.20,93.00},
			   {94.00,91.00,92.55,91.15},
			   {94.50,91.20,93.00,92.10},
			   {93.25,88.15,93.00,88.50},
			   {89.80,86.20,88.30,88.35},
			   {89.90,87.25,87.50,89.00},
			   {88.90,84.70,88.00,84.95},
			   {90.90,86.35,88.20,86.55},
			   {88.40,84.10,87.45,84.90},
			   {86.95,83.50,85.00,86.20},
			   {91.45,85.50,86.50,90.00},
			   {94.95,90.30,91.50,91.75},
			   {93.50,87.75,92.50,88.10},
			   {90.00,87.00,88.00,88.10},
			   {93.90,87.25,88.00,92.90},
			   {94.25,90.50,92.95,92.70},
			   {93.25,90.70,91.10,92.55},
			   {93.50,90.25,93.00,90.95},
			   {94.00,90.10,90.65,93.45},
			   {98.75,93.10,93.95,97.40},
			   {101.20,96.80,97.90,99.90},
			   {111.70,100.10,100.10,111.35},
			   {114.00,107.10,113.90,107.50},
			   {111.40,106.10,107.00,110.45},
			   {112.55,105.55,110.15,106.90},
			   {106.90,103.25,106.15,104.15},
			   {105.75,101.00,104.05,101.35},
			   {108.50,98.00,99.60,106.25},
			   {111.25,106.00,107.00,111.10},
			   {117.20,111.10,111.35,115.95},
			   {118.50,107.60,116.80,108.75},
			   {113.60,107.10,108.50,113.10},
			   {120.75,114.15,116.00,120.15},
			   {120.90,116.60,120.00,118.35},
			   {121.90,117.30,118.95,118.45},
			   {127.45,117.00,118.10,126.10},
			   {128.00,123.60,126.25,126.45},
			   {136.55,126.50,129.50,136.55},
			   {144.85,133.15,137.70,141.95},
			   {145.90,138.00,141.05,143.05},
			   {145.40,138.55,142.10,142.65},
			   {148.60,140.50,142.50,144.85},
			   {146.80,142.00,145.05,145.05},
			   {147.45,142.95,145.00,146.65},
			   {151.00,144.50,146.80,150.40},
			   {157.70,149.05,149.10,157.05},
			   {159.70,154.20,157.70,156.10},
			   {157.95,152.10,157.00,153.35},
			   {156.50,151.90,154.00,155.75},
			   {164.00,155.20,156.00,163.10},
			   {169.00,162.00,163.50,165.80},
			   {167.15,158.00,165.10,163.15},
			   {166.00,156.25,159.70,164.55},
			   {167.15,160.30,165.10,161.00},
			   {162.70,157.10,160.90,159.65},
			   {160.25,154.50,159.10,159.65},
			   {163.00,156.10,159.20,157.30},
			   {159.25,150.15,159.25,152.85},
			   {153.80,146.25,151.80,150.05},
			   {159.25,150.15,150.15,158.55},
			   {160.90,157.15,159.35,159.00},
			   {163.00,158.05,160.00,160.60},
			   {167.45,160.55,160.90,166.05},
			   {167.75,163.70,165.10,165.50},
			   {168.70,160.00,166.00,163.20},
			   {164.50,160.35,163.30,163.65},
			   {170.40,158.75,162.40,161.05},
			   {162.00,156.20,160.10,158.50},
			   {160.20,153.65,158.30,154.65},
			   {158.40,149.80,154.55,156.95},
			   {157.50,154.10,157.25,154.70},
			   {155.90,151.60,155.00,152.65},
			   {154.00,149.10,152.00,152.25},
			   {156.75,152.75,153.45,153.40},
			   {159.00,152.90,153.50,157.95},
			   {163.80,158.05,159.10,162.05},
			   {167.50,158.55,164.95,160.95},
			   {163.45,159.20,161.00,162.05},
			   {175.00,162.50,162.50,174.75},
			   {176.10,169.05,174.25,173.55},
			   {180.00,167.10,171.00,173.25},
			   {178.00,173.80,174.40,177.60},
			   {182.25,175.40,177.80,178.95},
			   {183.40,174.55,178.75,179.75},
			   {190.90,178.05,178.10,189.25},
			   {193.30,188.10,189.00,190.50},
			   {192.40,185.10,191.00,186.90},
			   {190.50,183.10,186.60,188.60},
			   {191.50,186.50,188.00,189.65},
			   {195.00,184.25,189.50,193.95},
			   {196.75,189.00,195.00,191.30},
			   {191.00,186.50,191.00,187.50},
			   {190.50,182.55,187.00,189.60},
			   {192.80,188.00,190.00,188.45},
			   {191.90,183.50,189.00,184.30}};
	
	return values;

    }

    // Values to the LMNB symbol
    private double[][] getLMNBValues() {
							 
	double[][] values={{191.90,183.50,189.00,184.30},
			   {192.80,188.00,190.00,188.45},
			   {190.50,182.55,187.00,189.60},
			   {191.00,186.50,191.00,187.50},
			   {196.75,189.00,195.00,191.30},
			   {195.00,184.25,189.50,193.95},
			   {191.50,186.50,188.00,189.65},
			   {190.50,183.10,186.60,188.60},
			   {192.40,185.10,191.00,186.90},
			   {193.30,188.10,189.00,190.50},
			   {190.90,178.05,178.10,189.25},
			   {183.40,174.55,178.75,179.75},
			   {182.25,175.40,177.80,178.95},
			   {178.00,173.80,174.40,177.60},
			   {180.00,167.10,171.00,173.25},
			   {176.10,169.05,174.25,173.55},
			   {175.00,162.50,162.50,174.75},
			   {163.45,159.20,161.00,162.05},
			   {167.50,158.55,164.95,160.95},
			   {163.80,158.05,159.10,162.05},
			   {159.00,152.90,153.50,157.95},
			   {156.75,152.75,153.45,153.40},
			   {154.00,149.10,152.00,152.25},
			   {155.90,151.60,155.00,152.65},
			   {157.50,154.10,157.25,154.70},
			   {158.40,149.80,154.55,156.95},
			   {160.20,153.65,158.30,154.65},
			   {162.00,156.20,160.10,158.50},
			   {170.40,158.75,162.40,161.05},
			   {164.50,160.35,163.30,163.65},
			   {168.70,160.00,166.00,163.20},
			   {167.75,163.70,165.10,165.50},
			   {167.45,160.55,160.90,166.05},
			   {163.00,158.05,160.00,160.60},
			   {160.90,157.15,159.35,159.00},
			   {159.25,150.15,150.15,158.55},
			   {153.80,146.25,151.80,150.05},
			   {159.25,150.15,159.25,152.85},
			   {163.00,156.10,159.20,157.30},
			   {160.25,154.50,159.10,159.65},
			   {162.70,157.10,160.90,159.65},
			   {167.15,160.30,165.10,161.00},
			   {166.00,156.25,159.70,164.55},
			   {167.15,158.00,165.10,163.15},
			   {169.00,162.00,163.50,165.80},
			   {164.00,155.20,156.00,163.10},
			   {156.50,151.90,154.00,155.75},
			   {157.95,152.10,157.00,153.35},
			   {159.70,154.20,157.70,156.10},
			   {157.70,149.05,149.10,157.05},
			   {151.00,144.50,146.80,150.40},
			   {147.45,142.95,145.00,146.65},
			   {146.80,142.00,145.05,145.05},
			   {148.60,140.50,142.50,144.85},
			   {145.40,138.55,142.10,142.65},
			   {145.90,138.00,141.05,143.05},
			   {144.85,133.15,137.70,141.95},
			   {136.55,126.50,129.50,136.55},
			   {128.00,123.60,126.25,126.45},
			   {127.45,117.00,118.10,126.10},
			   {121.90,117.30,118.95,118.45},
			   {120.90,116.60,120.00,118.35},
			   {120.75,114.15,116.00,120.15},
			   {113.60,107.10,108.50,113.10},
			   {118.50,107.60,116.80,108.75},
			   {117.20,111.10,111.35,115.95},
			   {111.25,106.00,107.00,111.10},
			   {108.50,98.00,99.60,106.25},
			   {105.75,101.00,104.05,101.35},
			   {106.90,103.25,106.15,104.15},
			   {112.55,105.55,110.15,106.90},
			   {111.40,106.10,107.00,110.45},
			   {114.00,107.10,113.90,107.50},
			   {111.70,100.10,100.10,111.35},
			   {101.20,96.80,97.90,99.90},
			   {98.75,93.10,93.95,97.40},
			   {94.00,90.10,90.65,93.45},
			   {93.50,90.25,93.00,90.95},
			   {93.25,90.70,91.10,92.55},
			   {94.25,90.50,92.95,92.70},
			   {93.90,87.25,88.00,92.90},
			   {90.00,87.00,88.00,88.10},
			   {93.50,87.75,92.50,88.10},
			   {94.95,90.30,91.50,91.75},
			   {91.45,85.50,86.50,90.00},
			   {86.95,83.50,85.00,86.20},
			   {88.40,84.10,87.45,84.90},
			   {90.90,86.35,88.20,86.55},
			   {88.90,84.70,88.00,84.95},
			   {89.90,87.25,87.50,89.00},
			   {89.80,86.20,88.30,88.35},
			   {93.25,88.15,93.00,88.50},
			   {94.50,91.20,93.00,92.10},
			   {94.00,91.00,92.55,91.15},
			   {96.90,92.90,96.20,93.00},
			   {97.00,94.25,95.00,95.90},
			   {96.40,91.10,93.00,94.70},
			   {94.70,91.50,92.10,92.25},
			   {97.50,91.10,97.00,91.65},
			   {98.30,95.50,96.45,97.30},
			   {99.40,96.15,97.50,97.10},
			   {103.50,96.00,100.15,97.75},
			   {105.80,97.65,105.80,98.10},
			   {108.70,105.05,106.00,106.20},
			   {106.45,104.00,105.80,105.90},
			   {107.85,103.10,105.40,104.45},
			   {109.40,105.00,108.00,106.35},
			   {114.90,108.50,114.00,108.95},
			   {115.50,113.20,115.40,113.90},
			   {116.95,114.50,116.45,115.25},
			   {118.75,116.40,118.00,116.80},
			   {121.80,115.95,117.00,118.50},
			   {118.50,115.00,117.50,115.30},
			   {119.90,117.00,118.35,118.20},
			   {121.20,117.55,121.20,118.40},
			   {125.50,121.35,122.30,121.55},
			   {127.50,122.10,126.00,123.55},
			   {126.75,122.50,123.80,124.50},
			   {125.45,121.60,125.00,123.30},
			   {126.50,122.70,124.10,124.20},
			   {128.10,122.10,123.25,124.70},
			   {124.80,115.00,116.50,121.80},
			   {117.70,113.00,117.40,116.10},
			   {119.80,116.00,116.25,116.65},
			   {117.80,115.20,115.95,116.40},
			   {117.00,114.10,115.50,115.70},
			   {115.25,113.05,113.90,113.95},
			   {121.30,112.20,121.00,113.15},
			   {126.90,120.10,126.00,121.45},
			   {126.00,119.75,121.25,125.00},
			   {121.00,113.25,115.00,120.65},
			   {117.90,114.00,117.00,115.95},
			   {119.50,115.50,115.90,117.40},
			   {115.90,106.15,109.70,115.20},
			   {115.75,107.50,114.40,109.05},
			   {116.00,111.55,113.70,114.65},
			   {119.40,112.25,117.50,112.80},
			   {118.85,110.10,112.50,116.70},
			   {115.40,104.00,107.35,113.05},
			   {110.05,105.10,105.10,108.00},
			   {109.50,104.35,107.50,106.50},
			   {109.80,103.00,106.20,107.85},
			   {119.00,106.25,116.00,107.45},
			   {117.40,106.10,109.00,114.85},
			   {120.00,107.00,117.00,110.10},
			   {128.50,120.60,127.20,121.35},
			   {133.60,123.05,132.30,126.10},
			   {137.50,129.55,136.50,132.10},
			   {140.90,136.40,139.00,137.55},
			   {139.90,134.50,136.00,139.30},
			   {135.85,130.60,133.00,134.00},
			   {138.40,132.00,136.90,132.25},
			   {136.80,130.05,130.90,136.15},
			   {132.15,128.00,130.40,130.35},
			   {134.40,128.70,131.80,129.85},
			   {131.25,125.00,125.90,129.45},
			   {128.70,124.80,126.15,125.20},
			   {133.25,127.00,127.75,127.30},
			   {128.00,120.75,121.10,127.00},
			   {125.00,118.60,120.00,120.70},
			   {122.80,117.50,122.10,117.95},
			   {123.50,118.20,118.75,122.00},
			   {120.00,117.30,118.85,117.95},
			   {121.00,116.00,116.60,118.15},
			   {117.75,114.00,114.60,116.20},
			   {119.50,115.10,116.00,116.00},
			   {117.30,114.00,116.40,116.80},
			   {120.80,115.50,119.90,115.90},
			   {125.00,118.00,123.90,119.55},
			   {126.70,121.50,124.95,122.50},
			   {123.00,119.10,121.50,122.70},
			   {124.80,121.15,123.30,121.60},
			   {126.80,120.50,120.50,123.10},
			   {122.00,118.30,119.00,120.30},
			   {123.40,118.55,120.00,119.65},
			   {122.20,116.50,118.00,117.65},
			   {118.00,112.20,113.00,117.15},
			   {114.45,111.20,111.70,112.30},
			   {114.35,110.00,114.00,112.00},
			   {117.95,112.60,113.00,113.05},
			   {112.00,107.00,107.00,110.70},
			   {113.20,103.00,112.25,109.20},
			   {123.85,112.20,122.00,113.50},
			   {125.00,118.50,125.00,120.90},
			   {130.00,123.00,128.40,124.00},
			   {126.00,113.00,114.00,125.50},
			   {115.50,106.75,106.90,114.40},
			   {108.00,97.00,99.00,106.45},
			   {102.50,96.00,97.50,99.50},
			   {107.35,95.50,105.00,96.80},
			   {108.50,105.75,107.35,106.20},
			   {112.50,107.20,111.00,108.60},
			   {113.90,109.10,112.00,110.80},
			   {114.40,110.25,112.00,110.50},
			   {118.35,108.50,118.35,111.50},
			   {122.00,111.75,120.50,112.60},
			   {122.85,116.00,120.00,120.20},
			   {128.85,120.10,127.00,120.65},
			   {128.95,115.50,123.00,126.95},
			   {127.30,122.65,125.00,123.00},
			   {128.40,120.00,126.50,124.10},
			   {130.25,122.60,129.00,125.85},
			   {131.45,124.50,128.00,129.70},
			   {144.80,128.00,142.15,128.70},
			   {143.50,138.60,143.45,139.00},
			   {149.00,140.55,149.00,142.70},
			   {150.75,139.90,142.00,149.00},
			   {144.20,135.00,144.20,139.90},
			   {152.85,143.50,149.90,144.95},
			   {148.00,139.00,148.00,143.85},
			   {156.00,144.65,153.50,148.50},
			   {160.00,149.00,155.25,152.00},
			   {156.85,134.10,135.10,155.00},
			   {154.00,143.75,154.00,145.25},
			   {162.00,154.20,159.00,154.80},
			   {165.00,157.05,165.00,160.00},
			   {175.00,164.00,169.80,166.00},
			   {167.10,155.90,156.50,167.10},
			   {163.90,150.00,161.40,154.75},
			   {155.45,140.00,145.80,155.45},
			   {159.85,139.50,155.00,143.95},
			   {151.60,140.00,141.00,151.60},
			   {142.00,128.00,129.15,140.40},
			   {132.85,127.00,130.00,131.50},
			   {138.40,129.05,137.80,130.45},
			   {137.50,127.00,130.95,137.40},
			   {139.90,130.25,137.00,131.85},
			   {137.00,132.10,136.75,133.70},
			   {143.00,135.00,141.90,135.00},
			   {139.10,129.40,129.40,139.10},
			   {132.50,126.30,132.00,128.85},
			   {136.30,128.00,134.50,128.00},
			   {144.20,134.00,134.00,135.70},
			   {138.25,127.00,128.50,134.90},
			   {137.70,125.75,134.00,128.45},
			   {139.10,130.00,139.00,131.35},
			   {146.00,136.00,146.00,138.50},
			   {153.00,142.10,153.00,143.10},
			   {159.20,141.50,155.10,154.00},
			   {147.45,146.10,147.45,147.45},
			   {146.50,136.55,144.60,136.55},
			   {163.20,148.40,161.95,148.40},
			   {163.90,154.00,160.10,161.30},
			   {179.50,160.20,174.60,160.20},
			   {174.50,167.00,168.00,174.10},
			   {173.00,161.10,163.00,163.20},
			   {165.50,160.00,163.00,163.75},
			   {173.80,159.10,170.00,160.90},
			   {178.00,167.05,175.00,169.00},
			   {180.00,173.00,178.00,174.25},
			   {184.45,173.15,184.00,174.10},
			   {188.00,180.00,185.00,182.60},
			   {189.70,182.80,184.00,184.50},
			   {205.00,182.30,199.00,182.95},
			   {208.00,197.00,204.00,198.10},
			   {206.35,194.30,197.00,199.00},
			   {202.80,189.50,196.00,196.45},
			   {214.00,193.10,211.25,196.15},
			   {207.35,190.10,191.10,207.35},
			   {195.60,190.00,192.00,192.00},
			   {195.50,186.55,191.00,187.25},
			   {196.95,189.20,194.00,190.00},
			   {196.00,183.50,183.95,192.90},
			   {185.00,178.00,179.00,182.50}};

	return values;

    }

    // Values to the EMBR symbol
    public double[][] getEMBRValues() {

	double[][] values={{131.90,123.50,129.00,124.30},
			   {132.80,128.00,130.00,128.45},
			   {130.50,122.55,127.00,129.60},
			   {131.00,126.50,131.00,127.50},
			   {136.75,129.00,135.00,131.30},
			   {135.00,124.25,129.50,133.95},
			   {131.50,126.50,128.00,129.65},
			   {130.50,123.10,126.60,128.60},
			   {132.40,125.10,131.00,126.90},
			   {133.30,128.10,129.00,130.50},
			   {130.90,118.05,118.10,129.25},
			   {123.40,114.55,118.75,119.75},
			   {122.25,115.40,117.80,118.95},
			   {118.00,113.80,114.40,117.60},
			   {120.00,107.10,111.00,113.25},
			   {116.10,109.05,114.25,113.55},
			   {115.00,102.50,102.50,114.75},
			   {103.45,99.20,101.00,102.05},
			   {107.50,98.55,104.95,100.95},
			   {103.80,98.05,99.10,102.05},
			   {99.00,92.90,93.50,97.95},
			   {96.75,92.75,93.45,93.40},
			   {94.00,89.10,92.00,92.25},
			   {95.90,91.60,95.00,92.65},
			   {97.50,94.10,97.25,94.70},
			   {98.40,89.80,94.55,96.95},
			   {100.20,93.65,98.30,94.65},
			   {102.00,96.20,100.10,98.50},
			   {110.40,98.75,102.40,101.05},
			   {104.50,100.35,103.30,103.65},
			   {108.70,100.00,106.00,103.20},
			   {107.75,103.70,105.10,105.50},
			   {107.45,100.55,100.90,106.05},
			   {103.00,98.05,100.00,100.60},
			   {100.90,97.15,99.35,99.00},
			   {99.25,90.15,90.15,98.55},
			   {93.80,86.25,91.80,90.05},
			   {99.25,90.15,99.25,92.85},
			   {103.00,96.10,99.20,97.30},
			   {100.25,94.50,99.10,99.65},
			   {102.70,97.10,100.90,99.65},
			   {107.15,100.30,105.10,101.00},
			   {106.00,96.25,99.70,104.55},
			   {107.15,98.00,105.10,103.15},
			   {109.00,102.00,103.50,105.80},
			   {104.00,95.20,96.00,103.10},
			   {96.50,91.90,94.00,95.75},
			   {97.95,92.10,97.00,93.35},
			   {99.70,94.20,97.70,96.10},
			   {97.70,89.05,89.10,97.05},
			   {91.00,84.50,86.80,90.40},
			   {87.45,82.95,85.00,86.65},
			   {86.80,82.00,85.05,85.05},
			   {88.60,80.50,82.50,84.85},
			   {85.40,78.55,82.10,82.65},
			   {85.90,78.00,81.05,83.05},
			   {84.85,73.15,77.70,81.95},
			   {76.55,66.50,69.50,76.55},
			   {68.00,63.60,66.25,66.45},
			   {67.45,57.00,58.10,66.10},
			   {61.90,57.30,58.95,58.45},
			   {60.90,56.60,60.00,58.35},
			   {60.75,54.15,56.00,60.15},
			   {53.60,47.10,48.50,53.10},
			   {58.50,47.60,56.80,48.75},
			   {57.20,51.10,51.35,55.95},
			   {51.25,46.00,47.00,51.10},
			   {48.50,38.00,39.60,46.25},
			   {45.75,41.00,44.05,41.35},
			   {46.90,43.25,46.15,44.15},
			   {52.55,45.55,50.15,46.90},
			   {51.40,46.10,47.00,50.45},
			   {54.00,47.10,53.90,47.50},
			   {51.70,40.10,40.10,51.35},
			   {41.20,36.80,37.90,39.90},
			   {38.75,33.10,33.95,37.40},
			   {34.00,30.10,30.65,33.45},
			   {33.50,30.25,33.00,30.95},
			   {33.25,30.70,31.10,32.55},
			   {34.25,30.50,32.95,32.70},
			   {33.90,27.25,28.00,32.90},
			   {30.00,27.00,28.00,28.10},
			   {33.50,27.75,32.50,28.10},
			   {34.95,30.30,31.50,31.75},
			   {31.45,25.50,26.50,30.00},
			   {26.95,23.50,25.00,26.20},
			   {28.40,24.10,27.45,24.90},
			   {30.90,26.35,28.20,26.55},
			   {28.90,24.70,28.00,24.95},
			   {29.90,27.25,27.50,29.00},
			   {29.80,26.20,28.30,28.35},
			   {33.25,28.15,33.00,28.50},
			   {34.50,31.20,33.00,32.10},
			   {34.00,31.00,32.55,31.15},
			   {36.90,32.90,36.20,33.00},
			   {37.00,34.25,35.00,35.90},
			   {36.40,31.10,33.00,34.70},
			   {34.70,31.50,32.10,32.25},
			   {37.50,31.10,37.00,31.65},
			   {38.30,35.50,36.45,37.30},
			   {39.40,36.15,37.50,37.10},
			   {43.50,36.00,40.15,37.75},
			   {45.80,37.65,45.80,38.10},
			   {48.70,45.05,46.00,46.20},
			   {46.45,44.00,45.80,45.90},
			   {47.85,43.10,45.40,44.45},
			   {49.40,45.00,48.00,46.35},
			   {54.90,48.50,54.00,48.95},
			   {55.50,53.20,55.40,53.90},
			   {56.95,54.50,56.45,55.25},
			   {58.75,56.40,58.00,56.80},
			   {61.80,55.95,57.00,58.50},
			   {58.50,55.00,57.50,55.30},
			   {59.90,57.00,58.35,58.20},
			   {61.20,57.55,61.20,58.40},
			   {65.50,61.35,62.30,61.55},
			   {67.50,62.10,66.00,63.55},
			   {66.75,62.50,63.80,64.50},
			   {65.45,61.60,65.00,63.30},
			   {66.50,62.70,64.10,64.20},
			   {68.10,62.10,63.25,64.70},
			   {64.80,55.00,56.50,61.80},
			   {57.70,53.00,57.40,56.10},
			   {59.80,56.00,56.25,56.65},
			   {57.80,55.20,55.95,56.40},
			   {57.00,54.10,55.50,55.70},
			   {55.25,53.05,53.90,53.95},
			   {61.30,52.20,61.00,53.15},
			   {66.90,60.10,66.00,61.45},
			   {66.00,59.75,61.25,65.00},
			   {61.00,53.25,55.00,60.65},
			   {57.90,54.00,57.00,55.95},
			   {59.50,55.50,55.90,57.40},
			   {55.90,46.15,49.70,55.20},
			   {55.75,47.50,54.40,49.05},
			   {56.00,51.55,53.70,54.65},
			   {59.40,52.25,57.50,52.80},
			   {58.85,50.10,52.50,56.70},
			   {55.40,44.00,47.35,53.05},
			   {50.05,45.10,45.10,48.00},
			   {49.50,44.35,47.50,46.50},
			   {49.80,43.00,46.20,47.85},
			   {59.00,46.25,56.00,47.45},
			   {57.40,46.10,49.00,54.85},
			   {60.00,47.00,57.00,50.10},
			   {68.50,60.60,67.20,61.35},
			   {73.60,63.05,72.30,66.10},
			   {77.50,69.55,76.50,72.10},
			   {80.90,76.40,79.00,77.55},
			   {79.90,74.50,76.00,79.30},
			   {75.85,70.60,73.00,74.00},
			   {78.40,72.00,76.90,72.25},
			   {76.80,70.05,70.90,76.15},
			   {72.15,68.00,70.40,70.35},
			   {74.40,68.70,71.80,69.85},
			   {71.25,65.00,65.90,69.45},
			   {68.70,64.80,66.15,65.20},
			   {73.25,67.00,67.75,67.30},
			   {68.00,60.75,61.10,67.00},
			   {65.00,58.60,60.00,60.70},
			   {62.80,57.50,62.10,57.95},
			   {63.50,58.20,58.75,62.00},
			   {60.00,57.30,58.85,57.95},
			   {61.00,56.00,56.60,58.15},
			   {57.75,54.00,54.60,56.20},
			   {59.50,55.10,56.00,56.00},
			   {57.30,54.00,56.40,56.80},
			   {60.80,55.50,59.90,55.90},
			   {65.00,58.00,63.90,59.55},
			   {66.70,61.50,64.95,62.50},
			   {63.00,59.10,61.50,62.70},
			   {64.80,61.15,63.30,61.60},
			   {66.80,60.50,60.50,63.10},
			   {62.00,58.30,59.00,60.30},
			   {63.40,58.55,60.00,59.65},
			   {62.20,56.50,58.00,57.65},
			   {58.00,52.20,53.00,57.15},
			   {54.45,51.20,51.70,52.30},
			   {54.35,50.00,54.00,52.00},
			   {57.95,52.60,53.00,53.05},
			   {52.00,47.00,47.00,50.70},
			   {53.20,43.00,52.25,49.20},
			   {63.85,52.20,62.00,53.50},
			   {65.00,58.50,65.00,60.90},
			   {70.00,63.00,68.40,64.00},
			   {66.00,53.00,54.00,65.50},
			   {55.50,46.75,46.90,54.40},
			   {48.00,37.00,39.00,46.45},
			   {42.50,36.00,37.50,39.50},
			   {47.35,35.50,45.00,36.80},
			   {48.50,45.75,47.35,46.20},
			   {52.50,47.20,51.00,48.60},
			   {53.90,49.10,52.00,50.80},
			   {54.40,50.25,52.00,50.50},
			   {58.35,48.50,58.35,51.50},
			   {62.00,51.75,60.50,52.60},
			   {62.85,56.00,60.00,60.20},
			   {68.85,60.10,67.00,60.65},
			   {68.95,55.50,63.00,66.95},
			   {67.30,62.65,65.00,63.00},
			   {68.40,60.00,66.50,64.10},
			   {70.25,62.60,69.00,65.85},
			   {71.45,64.50,68.00,69.70},
			   {84.80,68.00,82.15,68.70},
			   {83.50,78.60,83.45,79.00},
			   {89.00,80.55,89.00,82.70},
			   {90.75,79.90,82.00,89.00},
			   {84.20,75.00,84.20,79.90},
			   {92.85,83.50,89.90,84.95},
			   {88.00,79.00,88.00,83.85},
			   {96.00,84.65,93.50,88.50},
			   {100.00,89.00,95.25,92.00},
			   {96.85,74.10,75.10,95.00},
			   {94.00,83.75,94.00,85.25},
			   {102.00,94.20,99.00,94.80},
			   {105.00,97.05,105.00,100.00},
			   {115.00,104.00,109.80,106.00},
			   {107.10,95.90,96.50,107.10},
			   {103.90,90.00,101.40,94.75},
			   {95.45,80.00,85.80,95.45},
			   {99.85,79.50,95.00,83.95},
			   {91.60,80.00,81.00,91.60},
			   {82.00,68.00,69.15,80.40},
			   {72.85,67.00,70.00,71.50},
			   {78.40,69.05,77.80,70.45},
			   {77.50,67.00,70.95,77.40},
			   {79.90,70.25,77.00,71.85},
			   {77.00,72.10,76.75,73.70},
			   {83.00,75.00,81.90,75.00},
			   {79.10,69.40,69.40,79.10},
			   {72.50,66.30,72.00,68.85},
			   {76.30,68.00,74.50,68.00},
			   {84.20,74.00,74.00,75.70},
			   {78.25,67.00,68.50,74.90},
			   {77.70,65.75,74.00,68.45},
			   {79.10,70.00,79.00,71.35},
			   {86.00,76.00,86.00,78.50},
			   {93.00,82.10,93.00,83.10},
			   {99.20,81.50,95.10,94.00},
			   {87.45,86.10,87.45,87.45},
			   {86.50,76.55,84.60,76.55},
			   {103.20,88.40,101.95,88.40},
			   {103.90,94.00,100.10,101.30},
			   {119.50,100.20,114.60,100.20},
			   {114.50,107.00,108.00,114.10},
			   {113.00,101.10,103.00,103.20},
			   {105.50,100.00,103.00,103.75},
			   {113.80,99.10,110.00,100.90},
			   {118.00,107.05,115.00,109.00},
			   {120.00,113.00,118.00,114.25},
			   {124.45,113.15,124.00,114.10},
			   {128.00,120.00,125.00,122.60},
			   {129.70,122.80,124.00,124.50},
			   {145.00,122.30,139.00,122.95},
			   {148.00,137.00,144.00,138.10},
			   {146.35,134.30,137.00,139.00},
			   {142.80,129.50,136.00,136.45},
			   {154.00,133.10,151.25,136.15},
			   {147.35,130.10,131.10,147.35},
			   {135.60,130.00,132.00,132.00},
			   {135.50,126.55,131.00,127.25},
			   {136.95,129.20,134.00,130.00},
			   {136.00,123.50,123.95,132.90},
			   {125.00,118.00,119.00,122.50}};

	return values;

    }

    public static void main(String[] args) {
	Main m=new Main();
    }

}

